const setupDevContent = require("../setup/dev/index");
const setupServerContent = require("../setup/server/index");
const revitContent = require("../revit/index");
const databaseContent = require("../dev/database/index");
const dataCenterContent = require("../dev/data-center/index");
const paasContent = require("../dev/paas/index");
const revitCenterContent = require("../dev/revit-center/index");
const dataCenterScheme = require("../dev/data-center-scheme/index");
const libContent = require("../dev/lib/index");

module.exports = {
    title: "数字化交付后台开发文档",
    description: "博锐尚格数字化交付后台开发文档",
    base: "/doc/service/",
    plugins: [
        "@vuepress/last-updated",
        "plugin-back-to-top",
        [
            'vuepress-plugin-typescript',
            {
                tsLoaderOptions: {
                },
            },
        ],
        [
            'vuepress-plugin-mathjax',
            {
                target: 'svg',
                macros: {
                    '*': '\\times',
                },
            },
        ],
    ],
    markdown: {
        lineNumbers: true
    },
    themeConfig: {
        logo: "/assets/img/logos.png",
        nav: [
            {text: "首页", link: "/"},
            {
                text: "安装配置",
                items: [
                    {
                        text: "服务器配置",
                        items: [
                            {text: "CentoOS 部署", link: "/setup/server/centos/"},
                            {text: "Windows 部署", link: "/setup/server/windows/"}
                        ]
                    },
                    {
                        text: "开发环境",
                        items: [
                            {text: "IDEA", link: "/setup/dev/idea"},
                            {text: "Revit", link: "/setup/dev/revit"},
                            {text: "Visual Studio", link: "/setup/dev/vsts"}
                        ]
                    }

                ]

            },
            {
                text: "开发文档",
                items: [
                    {
                        text: "后台开发",
                        items: [
                            {text: "数据中心", link: "/dev/data-center/"},
                            {text: "物理世界同步", link: "/dev/dataplatform-sync/"},
                            {text: "模型管理", link: "/dev/revit-center/"},
                            {text: "数据中台参考", link: "/dev/paas/"},
                            {text: "服务支持库", link: "/dev/lib/"}
                        ]
                    },
                    {
                        text: "移动端开发",
                        items: [
                            { text: "Android 图形引擎", link: "http://http://adm.sagacloud.cn:8080/api/android/graphy/" }
                        ]
                    },
                    {
                        text: "数据库设计",
                        items: [
                            { text: "数据中心", link: "/dev/database/data-center/" },
                            { text: "系统图", link: "/dev/database/topo/" }
                        ]
                    },
                    {
                        text: "新版数据字典物理世界对接",
                        items: [
                            { text: "新版字典中台工具接口对接", link: "/dev/data-center-scheme/" },
                            // { text: "新版字典ADM对接", link: "/dev/data-center-scheme/" },
                            // { text: "新版字典对接数据中心", link: "/dev/data-center-scheme/" },
                            // { text: "新版物理世界对接数据中心", link: "/dev/data-center-scheme/" }
                        ]
                    },
                ]
            },
            {
                text: "API参考",
                items: [
                    {
                        text: "后台开发",
                        items: [
                            { text: "Kotlin支持库", link: "http://adm.sagacloud.cn:8080/api/server/kotlin" },
                            { text: "后台框架库", link: "http://adm.sagacloud.cn:8080/api/server/service" },
                            { text: "数据中心", link: "http://adm.sagacloud.cn:8080/api/server/datacenter" },
                            { text: "ADM后台", link: "http://adm.sagacloud.cn:8080/api/server/adm" }
                        ]
                    },
                    {
                        text: "移动端开发",
                        items: [
                            { text: "图形引擎", link: "http://http://adm.sagacloud.cn:8080/api/android/graphy/" }
                        ]
                    }
                ]
            },
            {
                text: "编码规范",
                items: [
                    { text: "C#", link: "/style/csharp/" },
                    { text: "Kotlin", link: "/style/kotlin/" },
                    { text: "Python", link: "/style/python/" },
                    { text: "SQL", link: "/style/sql/" },
                    { text: "TypeScript", link: "/style/typescript/" }
                ]
            }
        ],
        displayAllHeaders: true,
        sidebarDepth: 1,
        sidebar: {
            "/setup/server/" : setupServerContent,
            "/setup/dev/" : setupDevContent,
            "/revit/" : revitContent,
            "/dev/database/" : databaseContent,
            "/dev/data-center/" : dataCenterContent,
            "/dev/paas/" : paasContent,
            "/dev/revit-center/" : revitCenterContent,
            "/dev/data-center-scheme/" : dataCenterScheme,
            "/dev/lib/" : libContent,
        }
    }
};
